<?php
function maybeCreateRoll(&$tof,$newRollID, $rollID) {
	if ($newRollID) {
		$rollID = $tof->user['Username'].'/'.$newRollID;
		$tof->ct->addRoll(
			  array('RollID' => $rollID,
					'Owner' => $tof->uid));
	} 
	return $rollID;
}
?>